==> mx-cleanup_22.5.tar.xz: mx-cleanup-22.5/translations/mx-cleanup_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="51"/>
        <location filename="../mainwindow.cpp" line="316"/>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>MX Cleanup</source>
        <translation>MX Limpador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Pastas a Limpar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Ajudas várias (em inglês)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Esvaziar o Lixo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation>Lixo com mais de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="426"/>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Don&apos;t empty</source>
        <translation>Não esvaziar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <location filename="../mainwindow.ui" line="657"/>
        <source> days</source>
        <translation>dias</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>All users</source>
        <translation>Todos os usuários</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>Selected user</source>
        <translation>Usuário selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Clear APT Cache</source>
        <translation>Limpar a memória cache APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Old files</source>
        <translation>Arquivos antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>All files</source>
        <translation>Todos os arquivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>Free Disk Space for User</source>
        <translation>Espaço Livre em Disco para o Utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to repair</source>
        <translation>Selecionar utilizador a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="486"/>
        <source>Select user:</source>
        <translation>Selecione o usuário:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Ferramenta gráfica para analisar o uso do disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Executar o analisador de uso de disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="522"/>
        <source>Schedule</source>
        <translation>Agendar limpeza automática</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="534"/>
        <source>No automatic clean</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="541"/>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <source>Monthly</source>
        <translation>Mensalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Delete Logs</source>
        <translation>Eliminar os registros (Logs)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>All logs</source>
        <translation>Todos os registros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Old logs</source>
        <translation>Registros antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Logs older than:</source>
        <translation>Registros com mais de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Cleanup command done</source>
        <translation>Comando de limpeza feito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB foram limpos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Quick and safe removal of old files</source>
        <translation>Remoção rápida e segura de arquivos antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="321"/>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Este programa deve ser executado como administrador</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="40"/>
        <source>Quick safe removal of old files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-cleanup_22.7.02.tar.xz: mx-cleanup-22.7.02/translations/mx-cleanup_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="75"/>
        <location filename="../mainwindow.cpp" line="396"/>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>MX Cleanup</source>
        <translation>MX Limpador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Pastas a Limpar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Ajudas várias (em inglês)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Esvaziar o Lixo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation>Lixo com mais de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="426"/>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Don&apos;t empty</source>
        <translation>Não esvaziar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <location filename="../mainwindow.ui" line="657"/>
        <source> days</source>
        <translation>dias</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>All users</source>
        <translation>Todos os usuários</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>Selected user</source>
        <translation>Usuário selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Clear APT Cache</source>
        <translation>Limpar a memória cache APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Old files</source>
        <translation>Arquivos antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>All files</source>
        <translation>Todos os arquivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>Free Disk Space for User</source>
        <translation>Espaço Livre em Disco para o Utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <location filename="../mainwindow.ui" line="565"/>
        <source>Select user to repair</source>
        <translation>Selecionar utilizador a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="568"/>
        <source>Select user:</source>
        <translation>Selecione o usuário:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="699"/>
        <source>Kernel removal tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="705"/>
        <source>List and select kernels to remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Ferramenta gráfica para analisar o uso do disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Executar o analisador de uso de disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="478"/>
        <source>Schedule</source>
        <translation>Agendar limpeza automática</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>No automatic clean</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <source>Monthly</source>
        <translation>Mensalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Delete Logs</source>
        <translation>Eliminar os registros (Logs)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>All logs</source>
        <translation>Todos os registros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Old logs</source>
        <translation>Registros antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Logs older than:</source>
        <translation>Registros com mais de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Cleanup command done</source>
        <translation>Comando de limpeza feito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB foram limpos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>Quick and safe removal of old files</source>
        <translation>Remoção rápida e segura de arquivos antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Remove selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Similar kernels that can be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Other kernels that can be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Este programa deve ser executado como administrador</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Quick safe removal of old files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
